"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = AudioPlayer;
exports.SEED_DATA = void 0;

var React = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _expoAv = require("expo-av");

var _vectorIcons = require("@expo/vector-icons");

var _slider = _interopRequireDefault(require("@react-native-community/slider"));

var _componentTypes = require("../core/component-types");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

// @ts-nocheck
function formatDuration(duration) {
  if (duration === 0 || duration === 1) return "00:00";
  var seconds = Math.floor(duration / 1000 % 60),
      minutes = Math.floor(duration / (1000 * 60) % 60),
      hours = Math.floor(duration / (1000 * 60 * 60) % 24);
  hours = hours < 10 ? "0" + hours : hours;
  minutes = minutes < 10 ? "0" + minutes : minutes;
  seconds = seconds < 10 ? "0" + seconds : seconds;

  if (hours > 0) {
    return hours + ":" + minutes + ":" + seconds;
  }

  return minutes + ":" + seconds;
}

function AudioPlayer({
  source
}) {
  const [sound, setSound] = React.useState();
  const [playing, setPlay] = React.useState(false);
  const [loading, setLoading] = React.useState(false);
  const [durationMillis, setDurationMillis] = React.useState(1);
  const [isDraggingSlider, setIsDraggingSlider] = React.useState(false);
  const [sliderPositionMillis, setSliderPositionMillis] = React.useState(0);

  const onPlaybackStatusUpdate = status => {
    if (status.isPlaying && !isDraggingSlider) {
      setSliderPositionMillis(status.positionMillis);
    }
  };

  const setOnPlaybackStatusUpdate = () => {
    if (sound) {
      sound.setOnPlaybackStatusUpdate(onPlaybackStatusUpdate);
    }
  }; // React.useEffect(() => {
  //   setOnPlaybackStatusUpdate();
  // }, [isDraggingSlider]);


  React.useEffect(() => {
    return sound ? () => {
      sound.unloadAsync();
    } : undefined;
  }, [sound]);

  async function loadAudio() {
    setLoading(true);
    const {
      sound: s,
      status
    } = await _expoAv.Audio.Sound.createAsync(source);
    setSound(s);
    setLoading(false);
    setOnPlaybackStatusUpdate();

    if (status.durationMillis) {
      setDurationMillis(status.durationMillis);
    }

    s.setOnPlaybackStatusUpdate(onPlaybackStatusUpdate);
    await s.playAsync();
    setPlay(true);
  }

  async function playSound() {
    if (playing) {
      await sound.pauseAsync();
      setPlay(false);
      return;
    }

    if (sound) {
      await sound.playAsync();
      setPlay(true);
      return;
    }

    await loadAudio();
  }

  const setTrackPosition = async positionMillis => {
    if (sound) {
      await sound.setPositionAsync(positionMillis);
    }
  };

  const onSlidingComplete = sliderValue => {
    if (isDraggingSlider) {
      setIsDraggingSlider(false);
    }

    setTrackPosition(sliderValue);
  };

  const onSliderChange = () => {
    if (!isDraggingSlider) {
      setIsDraggingSlider(true);
    }
  };

  const iconName = loading ? "loading1" : !sound || !playing ? "play" : "pause";
  return /*#__PURE__*/React.createElement(_reactNative.View, {
    style: styles.container
  }, /*#__PURE__*/React.createElement(_reactNative.Pressable, {
    onPress: playSound,
    style: {
      cursor: "pointer",
      marginRight: 8
    }
  }, /*#__PURE__*/React.createElement(_vectorIcons.AntDesign, {
    name: iconName,
    size: 24
  })), /*#__PURE__*/React.createElement(_reactNative.Text, {
    style: {
      marginRight: 8
    }
  }, formatDuration(sliderPositionMillis || 0), " /", " ", formatDuration(durationMillis || 0)), /*#__PURE__*/React.createElement(_slider.default, {
    style: {
      flex: 1
    },
    minimumTrackTintColor: "#333",
    maximumTrackTintColor: "#000000",
    thumbTintColor: "black",
    minimumValue: 0,
    value: sliderPositionMillis,
    maximumValue: durationMillis,
    onValueChange: onSliderChange,
    onSlidingComplete: onSlidingComplete
  }));
}

const styles = _reactNative.StyleSheet.create({
  container: {
    backgroundColor: "#eee",
    paddingHorizontal: 16,
    paddingVertical: 8,
    borderRadius: 24,
    flexDirection: "row",
    alignItems: "center"
  }
});

const SEED_DATA = {
  name: "Audio Player",
  tag: "AudioPlayer",
  description: "Given a URL, plays sounds",
  category: _componentTypes.COMPONENT_TYPES.media,
  layout: {},
  props: {
    source: {
      group: _componentTypes.GROUPS.data,
      label: "URL",
      description: "The url of the sound",
      editable: true,
      required: true,
      defaultValue: "https://hwcdn.libsyn.com/p/9/e/2/9e224ffb4f3625c8/Nerdist_644_-_Ted_Melfi.mp3?c_id=8473543&cs_id=8473543&destination_id=18174&expiration=1607628092&hwt=f8327d4f551ec81f902e666647dc76f5",
      formType: _componentTypes.FORM_TYPES.sourceUrl,
      propType: _componentTypes.PROP_TYPES.OBJECT
    }
  }
};
exports.SEED_DATA = SEED_DATA;
//# sourceMappingURL=AudioPlayer.js.map