"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SEED_DATA = exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

var _color = _interopRequireDefault(require("color"));

var _Image = _interopRequireDefault(require("./Image"));

var _Card = _interopRequireDefault(require("./Card"));

var _Elevation = _interopRequireDefault(require("./Elevation"));

var _Icon = _interopRequireDefault(require("./Icon"));

var _StarRating = _interopRequireDefault(require("./StarRating"));

var _theming = require("../core/theming");

var _componentTypes = require("../core/component-types");

var _Config = _interopRequireDefault(require("./Config"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const ICON_CONTAINER_SIZE = _Config.default.cardIconSize * 2;
const ICON_CONTAINER_PADDING = _Config.default.cardIconSize / 2 - 1;

const CardContainerRating = ({
  image = _Config.default.cardImageUrl,
  title,
  leftDescription,
  rightDescription,
  icon,
  rating,
  aspectRatio = 1.5,
  elevation = 2,
  numColumns = 3,
  theme: {
    colors,
    borderRadius,
    typography,
    spacing
  },
  style,
  onPress
}) => {
  let titleStyle, rightDescriptionStyle;

  switch (numColumns) {
    case 2:
      titleStyle = typography.headline6;
      rightDescriptionStyle = typography.body2;
      break;

    case 3:
      titleStyle = typography.headline5;
      rightDescriptionStyle = typography.caption;
      break;
  }

  return /*#__PURE__*/_react.default.createElement(_Card.default, {
    style: style,
    onPress: onPress,
    numColumns: numColumns
  }, /*#__PURE__*/_react.default.createElement(_Elevation.default, {
    style: {
      elevation,
      borderRadius: borderRadius.global
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      borderRadius: borderRadius.global,
      overflow: "hidden",
      backgroundColor: colors.background //background color is needed for bug on android 9 - https://github.com/facebook/react-native/issues/25093

    }
  }, /*#__PURE__*/_react.default.createElement(_Image.default, {
    style: {
      aspectRatio
    },
    source: typeof image === "string" ? {
      uri: image
    } : image,
    resizeMode: "cover"
  }), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      padding: numColumns === 1 ? spacing.small : spacing.large
    }
  }, title ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      flexDirection: "row",
      alignItems: "center",
      justifyContent: "space-between"
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    numberOfLines: 1,
    style: [titleStyle, {
      color: colors.strong
    }]
  }, title)) : null, leftDescription ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    numberOfLines: 1,
    style: [typography.body2, {
      color: colors.medium,
      marginTop: numColumns === 3 ? spacing.text : spacing.text / 2
    }]
  }, leftDescription) : null, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      flexDirection: "row",
      justifyContent: "space-between",
      alignItems: "center",
      marginTop: numColumns === 3 ? spacing.large : spacing.medium
    }
  }, /*#__PURE__*/_react.default.createElement(_StarRating.default, {
    starSize: numColumns === 1 ? 10 : 16,
    rating: rating
  }), /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: [rightDescriptionStyle, {
      color: colors.medium,
      marginLeft: spacing.small
    }],
    numberOfLines: 1
  }, rightDescription))), icon ? /*#__PURE__*/_react.default.createElement(_Elevation.default, {
    style: {
      elevation: _Config.default.cardIconElevation,
      position: "absolute",
      top: spacing.medium,
      right: spacing.medium,
      width: ICON_CONTAINER_SIZE,
      height: ICON_CONTAINER_SIZE,
      padding: ICON_CONTAINER_PADDING,
      borderRadius: ICON_CONTAINER_SIZE,
      backgroundColor: (0, _color.default)(colors.strong).alpha(_Config.default.cardIconBackgroundOpacity).rgb().string()
    }
  }, /*#__PURE__*/_react.default.createElement(_Icon.default, {
    name: icon,
    size: _Config.default.cardIconSize,
    color: colors.surface
  })) : null)));
};

var _default = (0, _theming.withTheme)(CardContainerRating);

exports.default = _default;
const SEED_DATA_PROPS = {
  image: {
    group: _componentTypes.GROUPS.data,
    label: "Image",
    description: "Image",
    formType: _componentTypes.FORM_TYPES.remoteImage,
    propType: _componentTypes.PROP_TYPES.ASSET,
    defaultValue: null,
    editable: true,
    required: false
  },
  title: {
    group: _componentTypes.GROUPS.data,
    label: "Title",
    description: "Text to display",
    formType: _componentTypes.FORM_TYPES.string,
    propType: _componentTypes.PROP_TYPES.STRING,
    defaultValue: "Beautiful West Coast Villa",
    editable: true,
    required: false
  },
  leftDescription: {
    group: _componentTypes.GROUPS.data,
    label: "Left description",
    description: "Text to display on the left",
    formType: _componentTypes.FORM_TYPES.string,
    propType: _componentTypes.PROP_TYPES.STRING,
    defaultValue: "San Diego",
    editable: true,
    required: false
  },
  rightDescription: {
    group: _componentTypes.GROUPS.data,
    label: "Right description",
    description: "Text to display on the right",
    formType: _componentTypes.FORM_TYPES.string,
    propType: _componentTypes.PROP_TYPES.STRING,
    defaultValue: "$100",
    editable: true,
    required: false
  },
  icon: {
    group: _componentTypes.GROUPS.basic,
    label: "Icon",
    description: "Icon to display on the top right",
    formType: _componentTypes.FORM_TYPES.icon,
    propType: _componentTypes.PROP_TYPES.ASSET,
    defaultValue: null,
    editable: true,
    required: false
  },
  aspectRatio: {
    group: _componentTypes.GROUPS.basic,
    label: "Aspect ratio",
    description: "Aspect ratio of the image",
    formType: _componentTypes.FORM_TYPES.aspectRatio,
    propType: _componentTypes.PROP_TYPES.NUMBER,
    defaultValue: 1.5,
    editable: true,
    required: false
  },
  rating: {
    group: _componentTypes.GROUPS.data,
    label: "Rating",
    description: "Number of stars to show. A number 0-5.",
    formType: _componentTypes.FORM_TYPES.number,
    propType: _componentTypes.PROP_TYPES.NUMBER,
    defaultValue: 5,
    min: 0,
    max: 5,
    step: 1,
    precision: 0,
    editable: true,
    required: false
  },
  elevation: (0, _componentTypes.createElevationType)(2)
};
const SEED_DATA = [{
  name: "Medium Card (Rating)",
  tag: "CardContainerRating",
  description: "An elevated card with a title and description, that takes up half of its container.",
  category: _componentTypes.COMPONENT_TYPES.card,
  preview_image_url: "{CLOUDINARY_URL}/Card_ContainerRating_2col.png",
  supports_list_render: true,
  props: _objectSpread(_objectSpread({}, SEED_DATA_PROPS), {}, {
    numColumns: {
      label: "Number of Columns",
      description: "Numbre of columns",
      group: _componentTypes.GROUPS.uncategorized,
      formType: _componentTypes.FORM_TYPES.number,
      propType: _componentTypes.PROP_TYPES.NUMBER,
      defaultValue: 2,
      editable: false,
      required: false
    }
  }),
  layout: {}
}, {
  name: "Large Card (Rating)",
  tag: "CardContainerRating",
  description: "An elevated card with a title and description, that takes up its full container.",
  category: _componentTypes.COMPONENT_TYPES.card,
  preview_image_url: "{CLOUDINARY_URL}/Card_ContainerRating_3col.png",
  supports_list_render: true,
  props: _objectSpread(_objectSpread({}, SEED_DATA_PROPS), {}, {
    numColumns: {
      label: "Number of Columns",
      description: "Numbre of columns",
      group: _componentTypes.GROUPS.uncategorized,
      formType: _componentTypes.FORM_TYPES.number,
      propType: _componentTypes.PROP_TYPES.NUMBER,
      defaultValue: 3,
      editable: false,
      required: false
    }
  }),
  layout: {}
}];
exports.SEED_DATA = SEED_DATA;
//# sourceMappingURL=CardContainerRating.js.map