function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from "react";
import { View, Text } from "react-native";
import color from "color";
import Image from "./Image";
import Card from "./Card";
import Elevation from "./Elevation";
import Icon from "./Icon";
import { withTheme } from "../core/theming";
import { GROUPS, FORM_TYPES, PROP_TYPES, COMPONENT_TYPES, createElevationType, createNumColumnsType } from "../core/component-types";
import Config from "./Config";
const ICON_CONTAINER_SIZE = Config.cardIconSize * 2;
const ICON_CONTAINER_PADDING = Config.cardIconSize / 2 - 1;

const CardContainer = ({
  image = Config.cardImageUrl,
  title,
  leftDescription,
  rightDescription,
  textCentered,
  icon,
  aspectRatio = 1.5,
  elevation = 2,
  numColumns = 3,
  theme: {
    colors,
    borderRadius,
    typography,
    spacing
  },
  style,
  onPress
}) => {
  let textJustification;
  let titleStyle;

  if (textCentered && !rightDescription) {
    textJustification = "center";
  } else {
    textJustification = "space-between";
  }

  switch (numColumns) {
    case 2:
      titleStyle = typography.headline6;
      break;

    case 3:
      titleStyle = typography.headline5;
      break;
  }

  return /*#__PURE__*/React.createElement(Card, {
    style: style,
    onPress: onPress,
    numColumns: numColumns
  }, /*#__PURE__*/React.createElement(Elevation, {
    style: {
      elevation,
      borderRadius: borderRadius.global
    }
  }, /*#__PURE__*/React.createElement(View, {
    style: {
      borderRadius: borderRadius.global,
      overflow: "hidden",
      backgroundColor: colors.surface
    }
  }, /*#__PURE__*/React.createElement(Image, {
    style: {
      aspectRatio
    },
    source: typeof image === "string" ? {
      uri: image
    } : image,
    resizeMode: "cover"
  }), /*#__PURE__*/React.createElement(View, {
    style: {
      padding: spacing.large
    }
  }, title ? /*#__PURE__*/React.createElement(View, {
    style: {
      flexDirection: "row",
      alignItems: "center",
      justifyContent: textJustification
    }
  }, /*#__PURE__*/React.createElement(Text, {
    numberOfLines: 1,
    style: [titleStyle, {
      color: colors.strong
    }]
  }, title)) : null, leftDescription ? /*#__PURE__*/React.createElement(View, {
    style: {
      flexDirection: "row",
      justifyContent: textJustification,
      alignItems: "center",
      marginTop: numColumns === 3 ? spacing.text : spacing.text / 2
    }
  }, /*#__PURE__*/React.createElement(Text, {
    numberOfLines: 1,
    style: [typography.body2, {
      color: colors.medium
    }]
  }, leftDescription), rightDescription ? /*#__PURE__*/React.createElement(Text, {
    numberOfLines: 1,
    style: [typography.subtitle2, {
      color: colors.light
    }]
  }, rightDescription) : null) : null), icon ? /*#__PURE__*/React.createElement(Elevation, {
    style: {
      elevation: Config.cardIconElevation,
      position: "absolute",
      top: spacing.medium,
      right: spacing.medium,
      width: ICON_CONTAINER_SIZE,
      height: ICON_CONTAINER_SIZE,
      padding: ICON_CONTAINER_PADDING,
      borderRadius: ICON_CONTAINER_SIZE,
      backgroundColor: color(colors.strong).alpha(Config.cardIconBackgroundOpacity).rgb().string()
    }
  }, /*#__PURE__*/React.createElement(Icon, {
    name: icon,
    size: Config.cardIconSize,
    color: colors.surface
  })) : null)));
};

export default withTheme(CardContainer);
const SEED_DATA_PROPS = {
  image: {
    label: "Image",
    description: "Image",
    formType: FORM_TYPES.remoteImage,
    propType: PROP_TYPES.ASSET,
    defaultValue: null,
    editable: true,
    required: true,
    group: GROUPS.data
  },
  title: {
    label: "Title",
    description: "Text to display",
    formType: FORM_TYPES.string,
    propType: PROP_TYPES.STRING,
    defaultValue: "Beautiful West Coast Villa",
    editable: true,
    required: false,
    group: GROUPS.data
  },
  leftDescription: {
    label: "Left description",
    description: "Text to display on the left",
    formType: FORM_TYPES.string,
    propType: PROP_TYPES.STRING,
    defaultValue: "San Diego",
    editable: true,
    required: false,
    group: GROUPS.data
  },
  rightDescription: {
    label: "Right description",
    description: "Text to display on the right",
    formType: FORM_TYPES.string,
    propType: PROP_TYPES.STRING,
    defaultValue: "$100",
    editable: true,
    required: false,
    group: GROUPS.data
  },
  icon: {
    label: "Icon",
    description: "Icon to display on the top right",
    formType: FORM_TYPES.icon,
    propType: PROP_TYPES.STRING
    /* OR ASSET TODO TEST ME */
    ,
    defaultValue: null,
    editable: true,
    required: false,
    group: GROUPS.basic
  },
  aspectRatio: {
    label: "Aspect ratio",
    description: "Aspect ratio of the image",
    formType: FORM_TYPES.aspectRatio,
    propType: PROP_TYPES.NUMBER,
    defaultValue: 1.5,
    editable: true,
    required: false,
    group: GROUPS.basic
  },
  textCentered: {
    label: "Centered Text",
    description: "Whether to center the text",
    formType: FORM_TYPES.boolean,
    propType: PROP_TYPES.BOOLEAN,
    defaultValue: false,
    editable: true,
    required: false,
    group: GROUPS.basic
  },
  elevation: createElevationType(2)
};
export const SEED_DATA = [{
  name: "Medium Card",
  tag: "CardContainer",
  description: "An elevated card with a title and description, that takes up half of its container.",
  category: COMPONENT_TYPES.card,
  layout: null,
  props: _objectSpread(_objectSpread({}, SEED_DATA_PROPS), {}, {
    numColumns: createNumColumnsType({
      defaultValue: 2
    })
  })
}, {
  name: "Large Card",
  tag: "CardContainer",
  description: "An elevated card with a title and description, that takes up its full container.",
  category: COMPONENT_TYPES.card,
  layout: null,
  props: _objectSpread(_objectSpread({}, SEED_DATA_PROPS), {}, {
    numColumns: createNumColumnsType({
      defaultValue: 3
    })
  })
}];
//# sourceMappingURL=CardContainer.js.map