function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from "react";
import { withTheme } from "../core/theming";
import { COMPONENT_TYPES, FORM_TYPES, FIELD_NAME } from "../core/component-types";
import Row from "./Row";
import Checkbox from "./Checkbox";

const RowBodyCheckbox = ({
  title,
  subtitle,
  style,
  status = "unchecked",
  onPress = () => {},
  color,
  theme: {
    colors,
    typography
  }
}) => {
  return /*#__PURE__*/React.createElement(Row, {
    titleTypeStyle: typography.body1,
    titleColor: colors.medium,
    subtitleTypeStyle: typography.subtitle2,
    subtitleColor: colors.light,
    title: title,
    subtitle: subtitle,
    right: () => /*#__PURE__*/React.createElement(Checkbox, {
      status: status,
      color: color,
      onPress: onPress
    }),
    style: style
  });
};

export default withTheme(RowBodyCheckbox);
export const SEED_DATA = [{
  name: "Row Single Line Body Checkbox",
  tag: "RowBodyCheckbox",
  description: "A row with left aligned body text and a right aligned checkbox",
  preview_image_url: "{CLOUDINARY_URL}/Row_SingleLine_BodyCheckbox.png",
  category: COMPONENT_TYPES.deprecated,
  supports_list_render: true,
  props: {
    title: {
      label: "Title",
      description: "Text to display",
      formType: FORM_TYPES.string,
      defaultValue: "Beautiful West Coast Villa",
      editable: true
    },
    color: {
      label: "Checkbox color",
      description: "Custom color for Checkbox",
      editable: true,
      required: false,
      formType: FORM_TYPES.color
    },
    fieldName: _objectSpread(_objectSpread({}, FIELD_NAME), {}, {
      defaultValue: "checkboxValue",
      valuePropName: "status",
      handlerPropName: "onPress"
    })
  },
  layout: {}
}, {
  name: "Row Double Line Body Checkbox",
  tag: "RowBodyCheckbox",
  description: "A row with left aligned body text and subtitle text and a right aligned checkbox",
  category: COMPONENT_TYPES.deprecated,
  preview_image_url: "{CLOUDINARY_URL}/Row_DoubleLine_BodyCheckbox.png",
  supports_list_render: true,
  props: {
    title: {
      label: "Title",
      description: "Text to display",
      formType: FORM_TYPES.string,
      defaultValue: "Beautiful West Coast Villa",
      editable: true
    },
    subtitle: {
      label: "Subtitle",
      description: "Subtitle text to display",
      formType: FORM_TYPES.string,
      defaultValue: "San Diego",
      editable: true
    },
    color: {
      label: "Color",
      description: "Custom color for Checkbox",
      editable: true,
      required: false,
      formType: FORM_TYPES.color
    },
    fieldName: _objectSpread(_objectSpread({}, FIELD_NAME), {}, {
      defaultValue: "checkboxValue",
      valuePropName: "status",
      handlerPropName: "onPress"
    })
  },
  layout: {}
}];
//# sourceMappingURL=RowBodyCheckbox.js.map